@@ -46,37 +46,37 @@ pub fn gen_delegate(def: &TypeDef, gen: &Gen) -> TokenStream {
         #doc
         #[repr(transparent)]
         #[derive(::core::cmp::PartialEq, ::core::cmp::Eq, ::core::clone::Clone, ::core::fmt::Debug)]
-        pub struct #name(::windows::runtime::IUnknown, #(#struct_phantoms,)*) where #constraints;
+        pub struct #name(::windows::core::IUnknown, #(#struct_phantoms,)*) where #constraints;
         #cfg
         impl<#constraints> #name {
             pub fn new<#fn_constraint>(invoke: F) -> Self {
                 let com = #box_name {
                     vtable: &#box_name::VTABLE,
-                    count: ::windows::runtime::RefCount::new(1),
+                    count: ::windows::core::RefCount::new(1),
                     invoke,
                 };
                 unsafe {
-                    core::mem::transmute(::windows::runtime::alloc::boxed::Box::new(com))
+                    core::mem::transmute(::windows::core::alloc::boxed::Box::new(com))
                 }
             }
             #invoke
         }
         #cfg
-        unsafe impl<#constraints> ::windows::runtime::RuntimeType for #name {
-            const SIGNATURE: ::windows::runtime::ConstBuffer = #type_signature;
+        unsafe impl<#constraints> ::windows::core::RuntimeType for #name {
+            const SIGNATURE: ::windows::core::ConstBuffer = #type_signature;
         }
         #cfg
-        unsafe impl<#constraints> ::windows::runtime::Interface for #name {
+        unsafe impl<#constraints> ::windows::core::Interface for #name {
             type Vtable = #abi_name;
-            const IID: ::windows::runtime::GUID = #guid;
+            const IID: ::windows::core::GUID = #guid;
         }
         #cfg
         #[repr(C)]
         #[doc(hidden)]
         pub struct #abi_name(
-            pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr, iid: &::windows::runtime::GUID, interface: *mut ::windows::runtime::RawPtr) -> ::windows::runtime::HRESULT,
-            pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr) -> u32,
-            pub unsafe extern "system" fn(this: ::windows::runtime::RawPtr) -> u32,
+            pub unsafe extern "system" fn(this: ::windows::core::RawPtr, iid: &::windows::core::GUID, interface: *mut ::windows::core::RawPtr) -> ::windows::core::HRESULT,
+            pub unsafe extern "system" fn(this: ::windows::core::RawPtr) -> u32,
+            pub unsafe extern "system" fn(this: ::windows::core::RawPtr) -> u32,
             pub unsafe extern "system" fn #abi_signature,
             #(pub #abi_phantoms,)*
         ) where #constraints;
@@ -85,7 +85,7 @@ pub fn gen_delegate(def: &TypeDef, gen: &Gen) -> TokenStream {
         struct #box_definition where #constraints {
             vtable: *const #abi_name,
             invoke: F,
-            count: ::windows::runtime::RefCount,
+            count: ::windows::core::RefCount,
         }
         #cfg
         impl<#constraints #fn_constraint> #box_name {
@@ -96,12 +96,12 @@ pub fn gen_delegate(def: &TypeDef, gen: &Gen) -> TokenStream {
                 Self::Invoke,
                 #(#vtable_phantoms,)*
             );
-            unsafe extern "system" fn QueryInterface(this: ::windows::runtime::RawPtr, iid: &::windows::runtime::GUID, interface: *mut ::windows::runtime::RawPtr) -> ::windows::runtime::HRESULT {
-                let this = this as *mut ::windows::runtime::RawPtr as *mut Self;
+            unsafe extern "system" fn QueryInterface(this: ::windows::core::RawPtr, iid: &::windows::core::GUID, interface: *mut ::windows::core::RawPtr) -> ::windows::core::HRESULT {
+                let this = this as *mut ::windows::core::RawPtr as *mut Self;
 
-                *interface = if iid == &<#name as ::windows::runtime::Interface>::IID ||
-                    iid == &<::windows::runtime::IUnknown as ::windows::runtime::Interface>::IID ||
-                    iid == &<::windows::runtime::IAgileObject as ::windows::runtime::Interface>::IID {
+                *interface = if iid == &<#name as ::windows::core::Interface>::IID ||
+                    iid == &<::windows::core::IUnknown as ::windows::core::Interface>::IID ||
+                    iid == &<::windows::core::IAgileObject as ::windows::core::Interface>::IID {
                         &mut (*this).vtable as *mut _ as _
                     } else {
                         ::core::ptr::null_mut()
@@ -110,28 +110,28 @@ pub fn gen_delegate(def: &TypeDef, gen: &Gen) -> TokenStream {
                 // TODO: implement IMarshal
 
                 if (*interface).is_null() {
-                    ::windows::runtime::HRESULT(0x8000_4002) // E_NOINTERFACE
+                    ::windows::core::HRESULT(0x8000_4002) // E_NOINTERFACE
                 } else {
                     (*this).count.add_ref();
-                    ::windows::runtime::HRESULT(0)
+                    ::windows::core::HRESULT(0)
                 }
             }
-            unsafe extern "system" fn AddRef(this: ::windows::runtime::RawPtr) -> u32 {
-                let this = this as *mut ::windows::runtime::RawPtr as *mut Self;
+            unsafe extern "system" fn AddRef(this: ::windows::core::RawPtr) -> u32 {
+                let this = this as *mut ::windows::core::RawPtr as *mut Self;
                 (*this).count.add_ref()
             }
-            unsafe extern "system" fn Release(this: ::windows::runtime::RawPtr) -> u32 {
-                let this = this as *mut ::windows::runtime::RawPtr as *mut Self;
+            unsafe extern "system" fn Release(this: ::windows::core::RawPtr) -> u32 {
+                let this = this as *mut ::windows::core::RawPtr as *mut Self;
                 let remaining = (*this).count.release();
 
                 if remaining == 0 {
-                    ::windows::runtime::alloc::boxed::Box::from_raw(this);
+                    ::windows::core::alloc::boxed::Box::from_raw(this);
                 }
 
                 remaining
             }
             unsafe extern "system" fn Invoke #abi_signature {
-                let this = this as *mut ::windows::runtime::RawPtr as *mut Self;
+                let this = this as *mut ::windows::core::RawPtr as *mut Self;
                 #invoke_upcall
             }
         }
@@ -145,7 +145,7 @@ fn gen_winrt_constraint(sig: &MethodSignature, gen: &Gen) -> TokenStream {
         let tokens = gen_name(&return_sig.kind, gen);
 
         if return_sig.is_array {
-            quote! { ::windows::runtime::Array<#tokens> }
+            quote! { ::windows::core::Array<#tokens> }
         } else {
             tokens
         }
@@ -153,5 +153,5 @@ fn gen_winrt_constraint(sig: &MethodSignature, gen: &Gen) -> TokenStream {
         quote! { () }
     };
 
-    quote! { F: FnMut(#(#params),*) -> ::windows::runtime::Result<#return_sig> + 'static }
+    quote! { F: FnMut(#(#params),*) -> ::windows::core::Result<#return_sig> + 'static }
 }
