@@ -37,7 +37,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             quote! {
                 #cfg
                 #[inline]
-                pub unsafe fn #name<#constraints T: ::windows::runtime::Interface>(#params) -> ::windows::runtime::Result<T> {
+                pub unsafe fn #name<#constraints T: ::windows::core::Interface>(#params) -> ::windows::core::Result<T> {
                     #[cfg(windows)]
                     {
                         #link_attr
@@ -45,7 +45,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
                             fn #name(#(#abi_params),*) #abi_return_type;
                         }
                         let mut result__ = ::core::option::Option::None;
-                        #name(#(#args,)* &<T as ::windows::runtime::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
+                        #name(#(#args,)* &<T as ::windows::core::Interface>::IID, &mut result__ as *mut _ as *mut _).and_some(result__)
                     }
                     #[cfg(not(windows))]
                     unimplemented!("Unsupported target OS");
@@ -60,14 +60,14 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             quote! {
                 #cfg
                 #[inline]
-                pub unsafe fn #name<#constraints T: ::windows::runtime::Interface>(#params result__: *mut ::core::option::Option<T>) -> ::windows::runtime::Result<()> {
+                pub unsafe fn #name<#constraints T: ::windows::core::Interface>(#params result__: *mut ::core::option::Option<T>) -> ::windows::core::Result<()> {
                     #[cfg(windows)]
                     {
                         #link_attr
                         extern "system" {
                             fn #name(#(#abi_params),*) #abi_return_type;
                         }
-                        #name(#(#args,)* &<T as ::windows::runtime::Interface>::IID, result__ as *mut _ as *mut _).ok()
+                        #name(#(#args,)* &<T as ::windows::core::Interface>::IID, result__ as *mut _ as *mut _).ok()
                     }
                     #[cfg(not(windows))]
                     unimplemented!("Unsupported target OS");
@@ -83,14 +83,14 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             quote! {
                 #cfg
                 #[inline]
-                pub unsafe fn #name<#constraints>(#params) -> ::windows::runtime::Result<#return_type_tokens> {
+                pub unsafe fn #name<#constraints>(#params) -> ::windows::core::Result<#return_type_tokens> {
                     #[cfg(windows)]
                     {
                         #link_attr
                         extern "system" {
                             fn #name(#(#abi_params),*) #abi_return_type;
                         }
-                        let mut result__: <#return_type_tokens as ::windows::runtime::Abi>::Abi = ::core::mem::zeroed();
+                        let mut result__: <#return_type_tokens as ::windows::core::Abi>::Abi = ::core::mem::zeroed();
                         #name(#(#args,)* &mut result__).from_abi::<#return_type_tokens>(result__)
                     }
                     #[cfg(not(windows))]
@@ -105,7 +105,7 @@ pub fn gen_function(def: &MethodDef, gen: &Gen) -> TokenStream {
             quote! {
                 #cfg
                 #[inline]
-                pub unsafe fn #name<#constraints>(#params) -> ::windows::runtime::Result<()> {
+                pub unsafe fn #name<#constraints>(#params) -> ::windows::core::Result<()> {
                     #[cfg(windows)]
                     {
                         #link_attr
