@@ -14,9 +14,9 @@ pub fn gen_timespan() -> TokenStream {
                 ::core::time::Duration::from_nanos((value.Duration * 100) as u64)
             }
         }
-        impl<'a> ::windows::runtime::IntoParam<'a, TimeSpan> for ::core::time::Duration {
-            fn into_param(self) -> ::windows::runtime::Param<'a, TimeSpan> {
-                ::windows::runtime::Param::Owned(self.into())
+        impl<'a> ::windows::core::IntoParam<'a, TimeSpan> for ::core::time::Duration {
+            fn into_param(self) -> ::windows::core::Param<'a, TimeSpan> {
+                ::windows::core::Param::Owned(self.into())
             }
         }
     }
